@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Draw Guitar Chord Diagrams
 
-our $VERSION = '0.0302';
+our $VERSION = '0.0400';
 
 use Moo;
 use strictures 2;
@@ -26,14 +26,14 @@ has position => (
 );
 
 
-has string_num => (
+has strings => (
     is      => 'ro',
     isa     => sub { die "$_[0] is not a positive integer" unless $_[0] =~ /^[1-9]\d*$/ },
     default => sub { 6 },
 );
 
 
-has fret_num => (
+has frets => (
     is      => 'ro',
     isa     => sub { die "$_[0] is not a positive integer" unless $_[0] =~ /^[1-9]\d*$/ },
     default => sub { 5 },
@@ -66,7 +66,7 @@ has tuning => (
 
 
 has fretboard => (
-    is       => 'rw',
+    is       => 'ro',
     init_arg => undef,
 );
 
@@ -91,7 +91,7 @@ sub BUILD {
         $notes{$n} = [ map { $scale[ ($i + $_) % @scale ] } 0 .. @scale - 1 ];
     }
 
-    $self->fretboard(\%notes);
+    $self->{fretboard} = \%notes;
 }
 
 
@@ -107,32 +107,32 @@ sub draw {
 
     # Setup a new image
     my $i = Imager->new(
-        xsize => $SPACE + $self->string_num * $SPACE - $self->string_num,
-        ysize => $SPACE + $self->fret_num * $SPACE - $self->fret_num,
+        xsize => $SPACE + $self->strings * $SPACE - $self->strings,
+        ysize => $SPACE + $self->frets * $SPACE - $self->frets,
     );
     my $font = Imager::Font->new( file => $self->font );
     $i->box( filled => 1, color => $WHITE );
 
     # Draw the vertical string lines
-    for my $string (0 .. $self->string_num - 1) {
+    for my $string (0 .. $self->strings - 1) {
         $i->line(
             color => $BLUE,
             x1    => $SPACE + $string * $SPACE,
             y1    => $SPACE,
             x2    => $SPACE + $string * $SPACE,
-            y2    => $SPACE + ($self->fret_num - 1) * $SPACE,
+            y2    => $SPACE + ($self->frets - 1) * $SPACE,
             aa    => 1,
             endp  => 1
         );
     }
  
     # Draw the horizontal fret lines
-    for my $fret ( 0 .. $self->fret_num - 1 ) {
+    for my $fret ( 0 .. $self->frets - 1 ) {
         $i->line(
             color => $BLUE,
             x1    => $SPACE,
             y1    => $SPACE + $fret * $SPACE,
-            x2    => $SPACE + ($self->string_num - 1) * $SPACE,
+            x2    => $SPACE + ($self->strings - 1) * $SPACE,
             y2    => $SPACE + $fret * $SPACE,
             aa    => 1,
             endp  => 1
@@ -153,7 +153,7 @@ sub draw {
     }
 
     # Draw the note/mute markers
-    my $string = $self->string_num;
+    my $string = $self->strings;
 
     for my $note ( split //, $self->chord ) {
         if ( $note =~ /[xX]/ ) {
@@ -163,7 +163,7 @@ sub draw {
                 font  => $font,
                 text  => 'X',
                 color => $BLACK,
-                x     => $SPACE + ($self->string_num - $string) * $SPACE - $SPACE / 6,
+                x     => $SPACE + ($self->strings - $string) * $SPACE - $SPACE / 6,
                 y     => $SPACE - 2,
                 size  => $SPACE / 2,
                 aa    => 1,
@@ -178,7 +178,7 @@ sub draw {
                 font  => $font,
                 text  => 'O',
                 color => $BLACK,
-                x     => $SPACE + ($self->string_num - $string) * $SPACE - $SPACE / 6,
+                x     => $SPACE + ($self->strings - $string) * $SPACE - $SPACE / 6,
                 y     => $SPACE - 2,
                 size  => $SPACE / 2,
                 aa    => 1,
@@ -192,7 +192,7 @@ sub draw {
             $i->circle(
                 color => $BLACK,
                 r     => $SPACE / 5,
-                x     => $SPACE + ($self->string_num - $string) * $SPACE,
+                x     => $SPACE + ($self->strings - $string) * $SPACE,
                 y     => $SPACE + $SPACE / 2 + ($note - 1) * $SPACE,
             );
         }
@@ -207,7 +207,7 @@ sub draw {
         text  => scalar(chordname(@chord)),
         color => $BLACK,
         x     => $SPACE,
-        y     => $SPACE + $self->fret_num * $SPACE - $self->fret_num - $SPACE / 4,
+        y     => $SPACE + $self->frets * $SPACE - $self->frets - $SPACE / 4,
         size  => $SPACE / 2,
         aa    => 1,
     );
@@ -233,22 +233,22 @@ Music::GuitarChordDiagram - Draw Guitar Chord Diagrams
 
 =head1 VERSION
 
-version 0.0302
+version 0.0400
 
 =head1 SYNOPSIS
 
   use Music::GuitarChordDiagram;
 
   my $dia = Music::GuitarChordDiagram->new(
-    chord      => 'x02220',
-    position   => 1,
-    string_num => 6,
-    fret_num   => 5,
-    size       => 30,
-    outfile    => 'chord-diagram',
-    font       => '/path/to/TTF/font.ttf',
-    tuning     => [qw/E B G D A E/],
-    verbose    => 1,
+    chord    => 'x02220',
+    position => 1,
+    strings  => 6,
+    frets    => 5,
+    size     => 30,
+    outfile  => 'chord-diagram',
+    font     => '/path/to/TTF/font.ttf',
+    tuning   => [qw/E B G D A E/],
+    verbose  => 1,
   );
 
   $dia->draw();
@@ -307,17 +307,17 @@ left of the first fret.
 
 Default: 1
 
-=head2 string_num
+=head2 strings
 
-  $string_num = $dia->string_num;
+  $strings = $dia->strings;
 
 The number of strings.
 
 Default: 6
 
-=head2 fret_num
+=head2 frets
 
-  $fret_num = $dia->fret_num;
+  $frets = $dia->frets;
 
 The number of frets.
 
@@ -352,7 +352,7 @@ Default: /opt/X11/share/fonts/TTF/VeraMono.ttf
   $tuning = $dia->tuning;
 
 An arrayref of the string tuning.  The order of the notes is from highest string
-(1st) to lowest (6th).
+(1st) to lowest (6th).  For accidental notes, use flat (C<b>), not sharp (C<#>).
 
 Default: [ E B G D A E ]
 
